-- COLUMN ALIAS example from http://idealprogrammer.com 
-- PURPOSE: Column Alias allows you to change column headings and also allows 
--          you to group several columns into one.
--          There are three ways to do this:
--          1. AS column_name AS new_column_header
--          2. new_column_header = column_name or expression 
--          3. column_name new_column_header


-- SYNTAX: SELECT [ ALL | DISTINCT ] 
--			[TOP ( expression ) [PERCENT] [ WITH TIES ] ] 
--			 column1 AS displayname1, displayname2 = column_name2, column_name3 displayname3  
--			[ INTO new_table ] 
--			[ FROM { table_source } [ ,...n ] ] 
--			[ WHERE search_condition AND search_condition ] 
--			[ GROUP BY ] 
--			[ HAVING  search_condition  ] 


CREATE TABLE people(
     ID          int,
     firstname   varchar (20),
     lastname    varchar (20),
     statecode   varchar (2),
     alive       bit,
     height      int )
 GO

 


 INSERT INTO people (ID, firstname, lastname, statecode, alive, height) 
 VALUES (1,  'Paul', 'Revere', 'AL', 0, 72)
 GO
 
 INSERT INTO people (ID, firstname, lastname, statecode, alive, height) 
 VALUES (2,  'John', 'Lennon', 'NY', 0, 69)
 GO
 
 INSERT INTO people (ID, firstname, lastname, statecode, alive, height)
 VALUES (3,  'Steve', 'Martin', 'GA', 1, 75)
 GO
 
 INSERT INTO people (ID, firstname, lastname, statecode, alive, height)
 VALUES (4,  'George', 'Washington', 'MA', 0, 65)
 GO
 
--Show entire table
 SELECT * FROM people;
 GO
 	
-- Using AS to combine columns and to change column headings 
-- Brackets and single quotes can be used when column heading contains spaces
 SELECT firstname + ' ' + lastname AS [full name], height 'Height Inches',
  state = statecode  
  FROM people; 
 GO

 
 drop table people;
 
 GO
