/* Or example from http://idealprogrammer.com 
 
 PURPOSE: Returns true or false as the result of combining two expressions
 
 SYNTAX: expression1 OR expression2
 
 
 NOTE: When AND and OR are used in a condition,AND takes precedence over OR.
 
 SELECT [ ALL | DISTINCT ] 
			[TOP ( expression ) [PERCENT] [ WITH TIES ] ] 
			 column_list  
			[ INTO new_table ] 
			[ FROM { table_source } [ ,...n ] ] 
			[ WHERE expression1 OR expression2] 
			[ GROUP BY ] 
			[ HAVING  search_condition  ] 
			[ ORDER BY  order_expression [ ASC | DESC ] ] 
*/
 
 
CREATE TABLE people(
     ID          int,
     firstname   varchar (20),
     lastname    varchar (20),
     statecode   varchar (2),
     alive       bit,
     height      int )
 GO
 
 
 
 
 INSERT INTO people (ID, firstname, lastname, statecode, alive) --height is null 
 VALUES (1,  'Paul', 'Revere', 'AL', 0)
 GO
 
 INSERT INTO people (ID, firstname, lastname, statecode, alive, height) 
 VALUES (2,  'Pat', 'Lennon', 'NY', 0, 69)
 GO
 
 INSERT INTO people (ID, firstname, lastname, statecode, alive, height)
 VALUES (3,  'Peter', 'Martin', 'NY', 1, 75)
 GO
 
 INSERT INTO people (ID, firstname, lastname, statecode, alive, height)
 VALUES (4,  'George', 'Washington', 'VA', 0, 75)
 GO
 
 
 
 -- Select entire table
 SELECT 'Entire Table', * FROM people
 
 -- 1. Example of using OR with parentheses

 SELECT 'Example #1' as Example, firstname, lastname, height 
  FROM people p
  WHERE (firstname = 'Paul' and lastname = 'Revere')
  OR (firstname = 'George' and lastname = 'Washington')
  
 GO
 
 -- 2. Example of OR in simple query

DECLARE @bit bit   
SET @bit = 1 

SELECT 'Example #2' AS Example, @bit As bit
WHERE @bit = 0 OR @bit = 1

 
 
 
 DROP TABLE people;
 
 GO
 
 
 

 
 
 
 
 

