/* Operators example from http://idealprogrammer.com 
 
 PURPOSE: Operator is a symbol specifying an action that will take place on one or
          more expressions
 
 SYNTAX: 
 
 [expression1] operator expression2
 
 Here is a table of the various types of operators:
 
 Arithmetic Operators -          mathematical operations
 Assignment Operator -           assignment operations
 Bitwise Operators -             bit manipulations
 Comparison Operators -          compare equality of two expressions
 Logical Operators -             test for truth of some condition
 Scope Resolution Operator -     :: provides access to static members 
                                 of a compound data type
 String Concatenation Operator - + is used for string concatenation 
 Unary Operators -               + (positive), - negative, ~(bitwise not)
 
 



 
 SELECT [ ALL | DISTINCT ] 
			[TOP ( expression ) [PERCENT] [ WITH TIES ] ] 
			 column_list  
			[ INTO new_table ] 
			[ FROM { table_source } [ ,...n ] ] 
			[ WHERE expression1 operator expression2] 
			[ GROUP BY ] 
			[ HAVING  search_condition  ] 
			[ ORDER BY  order_expression [ ASC | DESC ] ] 
*/
 
 
CREATE TABLE people(
     ID          int,
     firstname   varchar (20),
     lastname    varchar (20),
     statecode   varchar (2),
     alive       bit,
     height      int )
 GO
 
 
 
 
 INSERT INTO people (ID, firstname, lastname, statecode, alive) --height is null 
 VALUES (1,  'Paul', 'Revere', 'AL', 0)
 GO
 
 INSERT INTO people (ID, firstname, lastname, statecode, alive, height) 
 VALUES (2,  'Pat', 'Lennon', 'NY', 0, 69)
 GO
 
 INSERT INTO people (ID, firstname, lastname, statecode, alive, height)
 VALUES (3,  'Peter', 'Martin', 'NY', 1, 75)
 GO
 
 INSERT INTO people (ID, firstname, lastname, statecode, alive, height)
 VALUES (4,  'George', 'Washington', 'VA', 0, 75)
 GO
 
 
 
 -- Select entire table
 SELECT 'Entire Table', * FROM people
 
 -- 1. Example of using comparison operator =

 SELECT 'Example #1' as Example, firstname, lastname, height 
  FROM people p
  WHERE firstname = 'Paul'
  
 GO
 
 -- 2. Example of logical operator AND

 SELECT 'Example #2' as Example, firstname, lastname, height 
  FROM people p
  WHERE firstname = 'Paul' AND lastname = 'Revere'
  
 GO
 
 -- 3. Example of using + for string concatenation
 

 SELECT 'Example #3' as Example, firstname + ' ' + lastname AS Fullname, height 
  FROM people p
 
  
 GO
 
 

 

 
 
 DROP TABLE people;
 
 GO
 
 
 

 
 
 
 
 

