/* SELECT INTO example from http://idealprogrammer.com 
 
 PURPOSE: SELECT INTO creates a new table in the default file group with the 
          columns and rows from the result set of the SELECT.  If you want
          to create a table in a database other than the default file group,
          fully qualify the table name - database.schema.table_name. The columns
          are created in the order that they are specified in the select clause.  
 
 SYNTAX: 
 
 [ INTO new_table ]

 
 
 SELECT [ ALL | DISTINCT ] 
			[TOP ( expression ) [PERCENT] [ WITH TIES ] ] 
			 column_list  
			[ INTO new_table ] 
			[ FROM { table_source } [ ,...n ] ] 
			[ WHERE select_condition] 
			[ GROUP BY ] 
			[ HAVING  search_condition  ] 
			[ ORDER BY  order_expression [ ASC | DESC ] ] 
*/
 
 
CREATE TABLE people(
     ID          INT,
     firstname   VARCHAR (20),
     lastname    VARCHAR (20),
     statecode   VARCHAR (2),
     alive       BIT,
     height      INT )
 GO
 
 CREATE TABLE addressbook(
     ID          INT,
     firstname   VARCHAR (20),
     lastname    VARCHAR (20),
     email   VARCHAR (50))
 
 GO
 
 
 
 
 INSERT INTO people (ID, firstname, lastname, statecode, alive, height) 
 VALUES (1,  'Paul', 'Revere', 'AL', 0, 72)
 GO
 
 INSERT INTO people (ID, firstname, lastname, statecode, alive, height) 
 VALUES (2,  'John', 'Lennon', 'NY', 0, 69)
 GO
 
 INSERT INTO people (ID, firstname, lastname, statecode, alive, height)
 VALUES (3,  'Steve', 'Martin', 'NY', 1, 75)
 GO
 
 INSERT INTO people (ID, firstname, lastname, statecode, alive, height)
 VALUES (4,  'George', 'Washington', 'VA', 0, 75)
 GO
 
 INSERT INTO addressbook (ID, firstname, lastname, email) 
 VALUES (1,  'Paul', 'Revere', 'paul@email.com')
 GO
 
 INSERT INTO addressbook (ID, firstname, lastname, email)
 VALUES (2,  'Wade', 'Harvey', 'wade@email.com')
 GO
 
 INSERT INTO addressbook (ID, firstname, lastname, email)
 VALUES (3,  'Jack', 'Powers', 'jack@email.com')
 GO
 
 INSERT INTO addressbook (ID, firstname, lastname, email)
 VALUES (4,  'George', 'Washington', 'george@email.com')
 GO
 
 
 
 
 
 
 
 -- 1. Example of using a varchar column 
 --    The sort will be alphabetic and ascending

 SELECT 'Example #1' as Example, p.firstname, p.lastname, a.email 
 INTO peopleaddress
  FROM people p 
  INNER JOIN addressbook a 
  ON p.firstname = a.firstname
  AND p.lastname = a.lastname
  
  SELECT firstname, email FROM master.dbo.peopleaddress;
  
  DROP TABLE master.dbo.peopleaddress;
   
 GO
 
 
 
 -- 2. Example of using an integer column and DESC
 --    Sort will be numeric and descending

SELECT 'Example #2' as Example, firstname, lastname, height 
  FROM people p
  ORDER BY height DESC
  
 GO
 
  -- 3. Example of using multiple columns and DESC
 --    Sort will be height ascending and then by first name descending

SELECT 'Example #3' as Example, firstname, lastname, height 
  FROM people p
  ORDER BY height, firstname DESC
  
 GO
 
  -- 4. Example of using ordinal position of column in select list
 --    Sort will be by first name 
 
 SELECT 'Example #4' as Example, firstname, lastname, height 
  FROM people p
  ORDER BY 2 -- firstname is the second column in select list
  
 GO
 
 DROP TABLE people;
 
 GO
 
 DROP TABLE addressbook;
 
 GO
 
 
 

 
 
 
 
 

